## pagarme-python
[![Build status](https://travis-ci.org/pagarme/pagarme-python.svg?branch=master)](https://secure.travis-ci.org/pagarme/pagarme-python)
[![Coverage](https://coveralls.io/repos/pagarme/pagarme-python/badge.svg?branch=master&service=github)](https://coveralls.io/github/pagarme/pagarme-python)

Pagar.me Python library

## Installing

This lib can be found on [pip](https://pypi.python.org/pypi/pagarme-python). To install it, use:

```
$ pip install pagarme-python
```

## Documentation

* [API Guide](https://docs.pagar.me/)

## Support
If you have any problem or suggestion please open an issue [here](https://github.com/pagarme/pagarme-python/issues).

## License

Check [here](LICENSE).
